@charset "UTF-8";
/*!
 * Bootstrap v4.6.0 (https://getbootstrap.com/)
 * Copyright 2011-2021 The Bootstrap Authors
 * Copyright 2011-2021 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 */
:root {
  --blue: #007bff;
  --indigo: #6610f2;
  --purple: #6f42c1;
  --pink: #e83e8c;
  --red: #dc3545;
  --orange: #fd7e14;
  --yellow: #ffc107;
  --green: #28a745;
  --teal: #20c997;
  --cyan: #17a2b8;
  --white: #fff;
  --gray: #6c757d;
  --gray-dark: #343a40;
  --primary: #007bff;
  --secondary: #6c757d;
  --success: #28a745;
  --info: #17a2b8;
  --warning: #ffc107;
  --danger: #dc3545;
  --light: #f8f9fa;
  --dark: #343a40;
  --breakpoint-xs: 0;
  --breakpoint-sm: 576px;
  --breakpoint-md: 768px;
  --breakpoint-lg: 992px;
  --breakpoint-xl: 1200px;
  --font-family-sans-serif: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", "Liberation Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  --font-family-monospace: SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
}

*,
*::before,
*::after {
  box-sizing: border-box;
}

html {
  font-family: sans-serif;
  line-height: 1.15;
  -webkit-text-size-adjust: 100%;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}

 main, nav {
  display: block;
}

body {
  margin: 0;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", "Liberation Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  color: #212529;
  text-align: left;
  background-color: #fff;
}

address {
  margin-bottom: 1rem;
  font-style: normal;
  line-height: inherit;
}


ul {
  margin-top: 0;
  margin-bottom: 1rem;
}


ul ul {
  margin-bottom: 0;
}


strong {
  font-weight: bolder;
}

a {
  color: #007bff;
  text-decoration: none;
  background-color: transparent;
}
a:hover {
  color: #0056b3;
  text-decoration: underline;
}

a:not([href]):not([class]) {
  color: inherit;
  text-decoration: none;
}
a:not([href]):not([class]):hover {
  color: inherit;
  text-decoration: none;
}

img {
  vertical-align: middle;
  border-style: none;
}

label {
  display: inline-block;
  margin-bottom: 0.5rem;
}

button {
  border-radius: 0;
}

button:focus:not(:focus-visible) {
  outline: 0;
}

input,
button,
select,
textarea {
  margin: 0;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}

button,
input {
  overflow: visible;
}

button,
select {
  text-transform: none;
}

[role=button] {
  cursor: pointer;
}

select {
  word-wrap: normal;
}

button,
[type=button],
[type=submit] {
  -webkit-appearance: button;
}

button:not(:disabled),
[type=button]:not(:disabled),
[type=submit]:not(:disabled) {
  cursor: pointer;
}

button::-moz-focus-inner,
[type=button]::-moz-focus-inner,
[type=submit]::-moz-focus-inner {
  padding: 0;
  border-style: none;
}

input[type=radio],
input[type=checkbox] {
  box-sizing: border-box;
  padding: 0;
}

textarea {
  overflow: auto;
  resize: vertical;
}

progress {
  vertical-align: baseline;
}

[type=number]::-webkit-inner-spin-button,
[type=number]::-webkit-outer-spin-button {
  height: auto;
}

[type=search] {
  outline-offset: -2px;
  -webkit-appearance: none;
}

[type=search]::-webkit-search-decoration {
  -webkit-appearance: none;
}

output {
  display: inline-block;
}

[hidden] {
  display: none !important;
}

.lead {
  font-size: 1.25rem;
  font-weight: 300;
}

.container {
  width: 100%;
  padding-right: 15px;
  padding-left: 15px;
  margin-right: auto;
  margin-left: auto;
}

@media (min-width: 576px) {
   .container {
    max-width: 540px;
  }
}
@media (min-width: 768px) {
   .container {
    max-width: 720px;
  }
}
@media (min-width: 992px) {
   .container {
    max-width: 960px;
  }
}
@media (min-width: 1200px) {
   .container {
    max-width: 1140px;
  }
}

.form-control {
  display: block;
  width: 100%;
  height: calc(1.5em + 0.75rem + 2px);
  padding: 0.375rem 0.75rem;
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  color: #495057;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid #ced4da;
  border-radius: 0.25rem;
  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}
@media (prefers-reduced-motion: reduce) {
  .form-control {
    transition: none;
  }
}
.form-control::-ms-expand {
  background-color: transparent;
  border: 0;
}
.form-control:-moz-focusring {
  color: transparent;
  text-shadow: 0 0 0 #495057;
}
.form-control:focus {
  color: #495057;
  background-color: #fff;
  border-color: #80bdff;
  outline: 0;
  box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
}
.form-control::placeholder {
  color: #6c757d;
  opacity: 1;
}
.form-control:disabled, .form-control[readonly] {
  background-color: #e9ecef;
  opacity: 1;
}

input[type=date].form-control,
input[type=time].form-control {
  appearance: none;
}

select.form-control:focus::-ms-value {
  color: #495057;
  background-color: #fff;
}

textarea.form-control {
  height: auto;
}

.btn {
  display: inline-block;
  font-weight: 400;
  color: #212529;
  text-align: center;
  vertical-align: middle;
  user-select: none;
  background-color: transparent;
  border: 1px solid transparent;
  padding: 0.375rem 0.75rem;
  font-size: 1rem;
  line-height: 1.5;
  border-radius: 0.25rem;
  transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}
@media (prefers-reduced-motion: reduce) {
  .btn {
    transition: none;
  }
}
.btn:hover {
  color: #212529;
  text-decoration: none;
}
.btn:focus, .btn.focus {
  outline: 0;
  box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
}
.btn.disabled, .btn:disabled {
  opacity: 0.65;
}
.btn:not(:disabled):not(.disabled) {
  cursor: pointer;
}
a.btn.disabled {
  pointer-events: none;
}

.fade {
  transition: opacity 0.15s linear;
}
@media (prefers-reduced-motion: reduce) {
  .fade {
    transition: none;
  }
}
.fade:not(.show) {
  opacity: 0;
}

.collapse:not(.show) {
  display: none;
}

.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  transition: height 0.35s ease;
}
@media (prefers-reduced-motion: reduce) {
  .collapsing {
    transition: none;
  }
}

.nav {
  display: flex;
  flex-wrap: wrap;
  padding-left: 0;
  margin-bottom: 0;
  list-style: none;
}

.navbar {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  justify-content: space-between;
  padding: 0.5rem 1rem;
}
.navbar .container {
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  justify-content: space-between;
}
.navbar-brand {
  display: inline-block;
  padding-top: 0.3125rem;
  padding-bottom: 0.3125rem;
  margin-right: 1rem;
  font-size: 1.25rem;
  line-height: inherit;
  white-space: nowrap;
}
.navbar-brand:hover, .navbar-brand:focus {
  text-decoration: none;
}

.navbar-toggler {
  padding: 0.25rem 0.75rem;
  font-size: 1.25rem;
  line-height: 1;
  background-color: transparent;
  border: 1px solid transparent;
  border-radius: 0.25rem;
}
.navbar-toggler:hover, .navbar-toggler:focus {
  text-decoration: none;
}

.card {
  position: relative;
  display: flex;
  flex-direction: column;
  min-width: 0;
  word-wrap: break-word;
  background-color: #fff;
  background-clip: border-box;
  border: 1px solid rgba(0, 0, 0, 0.125);
  border-radius: 0.25rem;
}
.card > .list-group {
  border-top: inherit;
  border-bottom: inherit;
}
.card > .list-group:first-child {
  border-top-width: 0;
  border-top-left-radius: calc(0.25rem - 1px);
  border-top-right-radius: calc(0.25rem - 1px);
}
.card > .list-group:last-child {
  border-bottom-width: 0;
  border-bottom-right-radius: calc(0.25rem - 1px);
  border-bottom-left-radius: calc(0.25rem - 1px);
}

@keyframes progress-bar-stripes {
  from {
    background-position: 1rem 0;
  }
  to {
    background-position: 0 0;
  }
}
.progress {
  display: flex;
  height: 1rem;
  overflow: hidden;
  line-height: 0;
  font-size: 0.75rem;
  background-color: #e9ecef;
  border-radius: 0.25rem;
}

.progress-bar {
  display: flex;
  flex-direction: column;
  justify-content: center;
  overflow: hidden;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  background-color: #007bff;
  transition: width 0.6s ease;
}
@media (prefers-reduced-motion: reduce) {
  .progress-bar {
    transition: none;
  }
}

.list-group {
  display: flex;
  flex-direction: column;
  padding-left: 0;
  margin-bottom: 0;
  border-radius: 0.25rem;
}

.list-group-item {
  position: relative;
  display: block;
  padding: 0.75rem 1.25rem;
  background-color: #fff;
  border: 1px solid rgba(0, 0, 0, 0.125);
}
.list-group-item:first-child {
  border-top-left-radius: inherit;
  border-top-right-radius: inherit;
}
.list-group-item:last-child {
  border-bottom-right-radius: inherit;
  border-bottom-left-radius: inherit;
}
.list-group-item.disabled, .list-group-item:disabled {
  color: #6c757d;
  pointer-events: none;
  background-color: #fff;
}
.list-group-item + .list-group-item {
  border-top-width: 0;
}

.close {
  float: right;
  font-size: 1.5rem;
  font-weight: 700;
  line-height: 1;
  color: #000;
  text-shadow: 0 1px 0 #fff;
  opacity: 0.5;
}
.close:hover {
  color: #000;
  text-decoration: none;
}
.close:not(:disabled):not(.disabled):hover, .close:not(:disabled):not(.disabled):focus {
  opacity: 0.75;
}

button.close {
  padding: 0;
  background-color: transparent;
  border: 0;
}

a.close.disabled {
  pointer-events: none;
}

.toast {
  flex-basis: 350px;
  max-width: 350px;
  font-size: 0.875rem;
  background-color: rgba(255, 255, 255, 0.85);
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.1);
  box-shadow: 0 0.25rem 0.75rem rgba(0, 0, 0, 0.1);
  opacity: 0;
  border-radius: 0.25rem;
}
.toast:not(:last-child) {
  margin-bottom: 0.75rem;
}
.toast.show {
  display: block;
  opacity: 1;
}
.toast.hide {
  display: none;
}

.toast-header {
  display: flex;
  align-items: center;
  padding: 0.25rem 0.75rem;
  color: #6c757d;
  background-color: rgba(255, 255, 255, 0.85);
  background-clip: padding-box;
  border-bottom: 1px solid rgba(0, 0, 0, 0.05);
  border-top-left-radius: calc(0.25rem - 1px);
  border-top-right-radius: calc(0.25rem - 1px);
}

.modal {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1050;
  display: none;
  width: 100%;
  height: 100%;
  overflow: hidden;
  outline: 0;
}

.modal-dialog {
  position: relative;
  width: auto;
  margin: 0.5rem;
  pointer-events: none;
}
.modal.fade .modal-dialog {
  transition: transform 0.3s ease-out;
  transform: translate(0, -50px);
}
@media (prefers-reduced-motion: reduce) {
  .modal.fade .modal-dialog {
    transition: none;
  }
}
.modal.show .modal-dialog {
  transform: none;
}

.modal-dialog-centered {
  display: flex;
  align-items: center;
  min-height: calc(100% - 1rem);
}
.modal-dialog-centered::before {
  display: block;
  height: calc(100vh - 1rem);
  height: min-content;
  content: "";
}

.modal-content {
  position: relative;
  display: flex;
  flex-direction: column;
  width: 100%;
  pointer-events: auto;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 0.3rem;
  outline: 0;
}

.modal-backdrop {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1040;
  width: 100vw;
  height: 100vh;
  background-color: #000;
}
.modal-backdrop.fade {
  opacity: 0;
}
.modal-backdrop.show {
  opacity: 0.5;
}

@media (min-width: 576px) {
  .modal-dialog {
    max-width: 500px;
    margin: 1.75rem auto;
  }

  .modal-dialog-centered {
    min-height: calc(100% - 3.5rem);
  }
  .modal-dialog-centered::before {
    height: calc(100vh - 3.5rem);
    height: min-content;
  }
}
.tooltip {
  position: absolute;
  z-index: 1070;
  display: block;
  margin: 0;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", "Liberation Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  font-style: normal;
  font-weight: 400;
  line-height: 1.5;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  white-space: normal;
  line-break: auto;
  font-size: 0.875rem;
  word-wrap: break-word;
  opacity: 0;
}
.tooltip.show {
  opacity: 0.9;
}

@keyframes spinner-border {
  to {
    transform: rotate(360deg);
  }
}

@keyframes spinner-grow {
  0% {
    transform: scale(0);
  }
  50% {
    opacity: 1;
    transform: none;
  }
}

.visible {
  visibility: visible !important;
}

.invisible {
  visibility: hidden !important;
}

@media print {
  *,
*::before,
*::after {
    text-shadow: none !important;
    box-shadow: none !important;
  }

  a:not(.btn) {
    text-decoration: underline;
  }

  
img {
    page-break-inside: avoid;
  }

  @page {
    size: a3;
  }
  body {
    min-width: 992px !important;
  }

  .container {
    min-width: 992px !important;
  }

  .navbar {
    display: none;
  }
}
/*!
 * Font Awesome Free 5.15.3 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 */

.fas,
.fab {
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  display: inline-block;
  font-style: normal;
  font-variant: normal;
  text-rendering: auto;
  line-height: 1;
}

@keyframes fa-spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}

/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
readers do not read off random characters that represent icons */

.fa-arrow-circle-right:before {
  content: "";
}

.fa-backward:before {
  content: "";
}

.fa-bars:before {
  content: "";
}

.fa-check-circle:before {
  content: "";
}

.fa-chevron-circle-down:before {
  content: "";
}

.fa-chevron-circle-up:before {
  content: "";
}

.fa-clock:before {
  content: "";
}

.fa-cog:before {
  content: "";
}

.fa-dice:before {
  content: "";
}

.fa-exclamation-circle:before {
  content: "";
}

.fa-exclamation-triangle:before {
  content: "";
}

.fa-fast-backward:before {
  content: "";
}

.fa-fast-forward:before {
  content: "";
}

.fa-forward:before {
  content: "";
}

.fa-github:before {
  content: "";
}

.fa-hdd:before {
  content: "";
}

.fa-headphones:before {
  content: "";
}

.fa-info-circle:before {
  content: "";
}

.fa-level-up-alt:before {
  content: "";
}

.fa-lightbulb:before {
  content: "";
}

.fa-link:before {
  content: "";
}

.fa-moon:before {
  content: "";
}

.fa-pause:before {
  content: "";
}

.fa-play:before {
  content: "";
}

.fa-play-circle:before {
  content: "";
}

.fa-plus-circle:before {
  content: "";
}

.fa-qrcode:before {
  content: "";
}

.fa-question-circle:before {
  content: "";
}

.fa-random:before {
  content: "";
}

.fa-reply:before {
  content: "";
}

.fa-robot:before {
  content: "";
}

.fa-search:before {
  content: "";
}

.fa-sliders-h:before {
  content: "";
}

.fa-sort:before {
  content: "";
}

.fa-soundcloud:before {
  content: "";
}

.fa-spotify:before {
  content: "";
}

.fa-stream:before {
  content: "";
}

.fa-sun:before {
  content: "";
}

.fa-sync:before {
  content: "";
}

.fa-times:before {
  content: "";
}

.fa-trash-alt:before {
  content: "";
}

.fa-user:before {
  content: "";
}

.fa-volume-down:before {
  content: "";
}

.fa-volume-off:before {
  content: "";
}

.fa-volume-up:before {
  content: "";
}

.fa-youtube:before {
  content: "";
}

/*!
 * Font Awesome Free 5.15.3 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 */
@font-face {
  font-family: "Font Awesome 5 Free";
  font-style: normal;
  font-weight: 900;
  font-display: block;
  src: url("/static/fa-solid-900.eot");
  src: url("/static/fa-solid-900.eot?#iefix") format("embedded-opentype"), url("/static/fa-solid-900.woff2") format("woff2"), url("/static/fa-solid-900.woff") format("woff"), url("/static/fa-solid-900.ttf") format("truetype"), url("/static/fa-solid-900.svg#fontawesome") format("svg");
}

.fas {
  font-family: "Font Awesome 5 Free";
  font-weight: 900;
}

/*!
 * Font Awesome Free 5.15.3 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 */
@font-face {
  font-family: "Font Awesome 5 Brands";
  font-style: normal;
  font-weight: 400;
  font-display: block;
  src: url("/static/fa-brands-400.eot");
  src: url("/static/fa-brands-400.eot?#iefix") format("embedded-opentype"), url("/static/fa-brands-400.woff2") format("woff2"), url("/static/fa-brands-400.woff") format("woff"), url("/static/fa-brands-400.ttf") format("truetype"), url("/static/fa-brands-400.svg#fontawesome") format("svg");
}
.fab {
  font-family: "Font Awesome 5 Brands";
  font-weight: 400;
}

body {
  background-color: #ffffff;
  -webkit-touch-callout: none;
  /* iOS Safari */
  -webkit-user-select: none;
  /* Safari */
  -khtml-user-select: none;
  /* Konqueror HTML */
  -moz-user-select: none;
  /* Firefox */
  -ms-user-select: none;
  /* Internet Explorer/Edge */
  user-select: none;
  /* Non-prefixed version, currently
     supported by Chrome and Opera */
}

.list-group-item {
  background-color: #f7f7f7;
  color: #495057;
}

.fas {
  color: #495057;
}

.fab {
  color: #495057;
}

.fas:active {
  color: #999999;
}

.fas.icon_disabled {
  color: #999999;
}

.fab.icon_disabled {
  color: #999999;
}

.fas.icon_enabled {
  color: #495057;
}

.information-banner {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
  z-index: 10;
  text-align: center;
  display: none;
}

.information-banner > i {
  color: #f7f7f7;
}

#disconnected-banner {
  background-color: #e64759;
}

#reconnected-banner {
  background-color: #1bc98e;
}

#update-banner {
  background-color: #e4d836;
}

#update_banner_buttons > span {
  display: inline-block;
  width: 30%;
  text-align: center;
  text-decoration: underline;
  cursor: pointer;
}

#toast-container {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
  height: 90vh;
  z-index: 10;
  pointer-events: none;
  display: flex;
  justify-content: center;
  align-items: flex-end;
}

.toast {
  position: fixed;
  margin: 10px;
  background-color: transparent;
  font-size: 1rem;
  display: none;
  opacity: 1;
}

.toast i {
  margin-right: 0.75rem;
  font-size: x-large;
}

.toast.error i {
  color: #e64759;
}

.toast.warning i {
  color: #e4d836;
}

.toast.success i {
  color: #1bc98e;
}

.toast.info i {
  color: #1997c6;
}

.toast .toast-header {
  color: #495057;
  border-color: #ced4da;
  background-color: #f7f7f7;
}

.modal .modal-content {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
  padding: 5px;
  background-color: #f7f7f7;
  color: #495057;
}

.ripple {
  width: 0;
  height: 0;
  border-radius: 50%;
  background: rgba(255, 255, 255, 0.4);
  transform: scale(0);
  position: absolute;
  opacity: 1;
}

.rippleEffect {
  animation: rippleDrop 0.4s linear;
}

@keyframes rippleDrop {
  100% {
    transform: scale(2);
    opacity: 0;
  }
}
.anim-container {
  height: 2rem;
  width: 2rem;
  font-size: 0.5rem;
  transition: 0.3s;
  position: relative;
}

.anim-container i {
  position: absolute;
  font-size: 4em !important;
  height: 1em;
  width: 1em;
  transition: 0.3s;
}

.anim-container .default {
  opacity: 1;
  transform: rotate(0);
}

.anim-container .other {
  opacity: 0;
  transform: rotate(-135deg);
}

.anim-container.morphed .default {
  opacity: 0;
  transform: rotate(135deg);
}

.anim-container.morphed .other {
  opacity: 1;
  transform: rotate(0);
}

.list_header {
  font-size: x-large;
}

.list_item {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.list_header {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.list_item.centered {
  justify-content: center;
}

.list_item > * {
  width: 50%;
  max-width: 200px;
}

.list_item > div {
  text-align: center;
}

.list_item > button {
  margin: 0px 10px;
}

.btn {
  background-color: #1997c6;
  color: #f7f7f7;
}

.autoscrolling_container {
  white-space: nowrap;
  overflow: hidden;
}

.autoscrolling_container > span.autoscrolling {
  display: inline-block;
}

.navbar {
  padding-bottom: 0px;
}

.navbar-brand {
  margin: 0px;
}

.navbar-toggler {
  background-color: #f7f7f7;
  border-color: #ced4da;
}

.alarm {
  animation: fade 2.5s linear 4;
}

@keyframes fade {
  0% {
    background-color: #ffffff;
  }
  /*
   18% {background-color: theme-color("red");}
   48% {background-color: theme-color("red");}
   */
  18% {
    background-color: red;
  }
  48% {
    background-color: red;
  }
  80% {
    background-color: #ffffff;
  }
  100% {
    background-color: #ffffff;
  }
}
#hashtag_container {
  width: 60%;
  text-align: center;
}

#hashtag_container > i {
  color: #495057;
  display: inline-block;
}

#hashtag_text_container {
  color: #495057;
  vertical-align: middle;
  display: inline-block;
  transition: max-width 0.5s ease;
  /* subtract space for the plus icon */
  overflow: hidden;
  white-space: nowrap;
  max-width: 70%;
}

#hashtag_input {
  visibility: hidden;
  transition: max-width 0.5s ease;
}

#hashtag_input.shown, #hashtag_text_container.shown {
  visibility: visible;
  max-width: 70%;
}

#hashtag_input.hidden, #hashtag_text_container.hidden {
  max-width: 0%;
}

#menu {
  margin: 16px;
  margin-bottom: 0px;
  font-size: xx-large;
}

#menu i {
  padding: 5px;
}

.menu_row {
  display: flex;
  justify-content: space-between;
}

#users_container {
  width: 25%;
  display: flex;
  align-items: center;
  justify-content: flex-start;
}

#users_container > * {
  padding: 5px;
}

#users {
  color: #495057;
}

#visitors_container {
  width: 50%;
  color: #495057;
  display: flex;
  flex-direction: column;
  align-items: center;
  font-size: medium;
}

#visitors {
  font-size: x-large;
}

#theme_controls {
  width: 25%;
  display: flex;
  align-items: center;
  justify-content: flex-end;
}

#theme_controls > i.icon_enabled {
  color: #252830;
}

#lights_controls {
  width: 25%;
  max-width: 80px;
  display: flex;
  align-items: center;
  justify-content: flex-end;
}

#lights_indicator.icon_enabled {
  color: yellow;
}

#presence {
  width: 25%;
  max-width: 80px;
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  display: none;
}

#presence > div {
  margin: 3px;
}

.presence_circle {
  height: 25px;
  width: 25px;
  line-height: 25px;
  text-align: center;
  border-radius: 50%;
}

.presence_circle.present {
  background-color: #1bc98e;
}

.presence_circle.absent {
  background-color: #e64759;
}

#additional_presence {
  color: #495057;
}

#content {
  padding: 8px;
}

#platform_controls {
  width: 25%;
  display: flex;
  align-items: center;
  justify-content: center;
}

#platform_controls > i.icon_enabled#youtube {
  color: red;
}

#platform_controls > i.icon_enabled#spotify {
  color: #1ED760;
}

#platform_controls > i.icon_enabled#soundcloud {
  color: #F95401;
}

.unlink {
  color: #495057;
}

#content > ul {
  margin-bottom: 10px;
}

#music_input_card {
  padding-left: 5px;
  padding-right: 5px;
  display: inline-flex;
}

#music_input_card > i {
  margin: 7px 2px;
  font-size: x-large;
}

#music_input_card .anim-container {
  margin: 7px 2px;
  height: 1.5rem;
  width: 1.5rem;
  min-width: 1.5rem;
  font-size: 0.375rem;
}

#music_input {
  padding: 6px;
  min-width: 100px;
  padding-right: 20px;
}

span.clearable {
  position: relative;
  margin: 0px 5px;
  width: 100%;
}

span.clearable i {
  position: absolute;
  display: block;
  top: 10px;
  right: 10px;
  font-size: large;
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.2s ease;
}

span.clearable input {
  padding-right: 16px;
  box-sizing: border-box;
}

.ui-autocomplete {
  position: absolute;
  z-index: 1000;
  cursor: default;
  padding: 0;
  margin-top: 2px;
  list-style: none;
  background-color: #ffffff;
  border: 1px solid #ccc;
  color: #495057;
  border-radius: 5px;
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  max-height: 200px;
  overflow-y: auto;
}

.ui-autocomplete > li {
  padding: 3px 5px;
}

.ui-menu-item-with-icon {
  display: flex;
  justify-content: space-between;
  word-break: break-all;
}

.autocomplete_info {
  color: #495057;
  flex: 0 0 auto;
  padding-left: 5px;
}

.insert_icon {
  padding-left: 5px;
}

.suggestion_type {
  width: 20px;
  padding-right: 5px;
  text-align: center;
}

.additional_keywords {
  padding-left: 5px;
  color: #999999;
  font-style: italic;
}

.forbidden_keywords {
  padding-left: 5px;
  color: #999999;
  text-decoration: line-through;
}

#current_song {
  text-align: center;
  font-size: larger;
  padding-left: 8px;
  padding-right: 8px;
}

#progress_bar_container {
  padding: 0px;
}

#progress_bar_container > .progress {
  height: 5px;
  background-color: #ced4da;
}

#progress_bar {
  width: 0%;
  transition: none;
}

#song_votes {
  text-align: center;
  font-size: x-large;
}

#song_controls {
  text-align: center;
}

#song_control_icons > i {
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 10px;
  padding-right: 10px;
  display: inline-block;
  font-size: x-large;
}

#song_control_icons .anim-container {
  display: inline-block;
  height: 1.5rem;
  width: 1.5rem;
  min-width: 1.5rem;
  margin-right: 31px;
}

#additional_controls {
  text-align: center;
  display: flex;
  justify-content: space-between;
}

#additional_controls i {
  font-size: x-large;
}

#total_time_container {
  display: flex;
  width: 25%;
}

#total_time {
  margin-left: 5px;
}

#volume_slider {
  max-width: 200px;
  width: 80%;
}

#volume_slider_container {
  width: 50%;
}

#trash_container {
  width: 25%;
  display: flex;
  justify-content: flex-end;
}

#song_queue > li {
  padding: 5px;
}

.queue_entry {
  display: flex;
  flex-wrap: wrap;
  flex-direction: column;
  height: 50px;
}

.download_icon {
  position: relative;
  height: 100%;
  width: 50px;
  display: flex;
  justify-content: center;
  align-items: center;
}

.download_icon img {
  max-height: 100%;
  max-width: 100%;
  height: 70%;
}

.download_overlay {
  position: absolute;
  width: 100%;
  height: 100%;
  animation: downloading 2s linear infinite;
  background: linear-gradient(transparent 50%, #f7f7f7 0%);
  background-size: 200% 200%;
}

@keyframes downloading {
  0% {
    background-position: 0% 100%;
  }
  60% {
    background-position: 0% 0%;
  }
  100% {
    background-position: 0% 0%;
  }
}
.queue_index {
  flex: 0 0 100%;
  width: 50px;
  line-height: 50px;
  text-align: center;
  font-size: larger;
  font-weight: bold;
}

.queue_title, .queue_info {
  word-break: break-all;
  overflow: hidden;
  flex: 0 0 50%;
  order: 1;
  width: calc(100% - 50px);
  padding-left: 5px;
  padding-right: 5px;
}

.queue_info_time {
  font-size: small;
}

.queue_info_controls {
  float: right;
}

.queue_info_controls > i {
  padding-left: 8px;
  padding-right: 8px;
}

.vote_up.pressed {
  color: #1bc98e;
}

.vote_down.pressed {
  color: #e64759;
}

#vote_timeout {
  width: 100%;
  height: 5px;
}

#vote_timeout_bar {
  height: 100%;
}

input[type=color] {
  padding: 0;
  border: none;
}

.disabled .list_header {
  color: #999999;
}

#most_active_device {
  white-space: pre;
}

#request_activity {
  white-space: pre;
}

#playlist {
  white-space: pre;
}

#upgrade_config {
  white-space: pre;
  margin-top: 20px;
  margin-bottom: 20px;
}

#changelog_modal .modal-content {
  display: flex;
  flex-direction: column;
}

#changelog {
  width: 100%;
}

#upgrade_modal .modal-content {
  display: flex;
  flex-direction: column;
}

.system-install-only.is-disabled {
  pointer-events: none;
  position: relative;
  opacity: 0.5;
}
.system-install-only.is-disabled:after {
  position: absolute;
  content: attr(disabled-note) "";
  width: 100%;
  text-align: center;
  top: 30%;
  color: white;
}

#show_password {
  cursor: pointer;
}

#network_info .list_item > span:only-child {
  width: 100%;
  max-width: unset;
}

/*# sourceMappingURL=light.css.map */
